@@ -136,8 +136,12 @@ def is_classification(model_name):
         else:
             raise ValueError('현재 설정한 loss는 지원되지 않습니다. 관리자에게 문의하십시오.')
             
-def feature_name(savedPath, bucketInfo, targetName):
-    fileType = bucketInfo['fileName'].split('.')[1]
+def feature_name(savedPath, StorageInfo, targetName):
+    if 'host' in StorageInfo:  # HDFS
+        fileType = StorageInfo['filePath'].split('.')[1]
+    
+    else: # AWS S3
+        fileType = StorageInfo['fileName'].split('.')[1]
         
     if fileType == 'json':
         with open(savedPath) as jsonFile:
